==> 1.0.1.tar.gz: lib/src/core/widgets/pickers/ModernFormDateRangePicker.dart <==
part of modern_form_core;

class ModernFormDateRangePicker extends StatelessWidget {
  final String? label;
  final String? helperText;
  final Icon? prefixIcon;
  final DateTimeRange? initialValute;
  final void Function(DateTimeRange selecteds)? onSelected;
  final bool? sufixCloseEnabled;
  final bool? enabled;
  final String Function(dynamic)? validator;

  const ModernFormDateRangePicker({
    Key? key,
    this.label,
    this.initialValute,
    this.prefixIcon,
    this.onSelected,
    this.sufixCloseEnabled = true,
    this.enabled,
    this.validator,
    this.helperText,
  });

  @override
  Widget build(BuildContext context) {
    DateTimeRange initialDateRange;
    initialDateRange = DateTimeRange(
      start: initialValute?.start ?? DateTime.now(),
      end: initialValute?.end ?? DateTime.now().add(Duration(days: 7)),
    );

    return ModernFormFakeTextField(
      label: label ?? "",
      helperText: helperText,
      validator: validator,
      initialValue: formatDate(initialDateRange),
      sufixIconEnabled: sufixCloseEnabled != null && sufixCloseEnabled!,
      enabled: enabled ?? true,
      onTap: () async {
        DateTimeRange? picked = await showDateRangePicker(
          context: context,
          initialDateRange: initialDateRange,
          firstDate: DateTime(2020, 01, 01, 00, 00),
          lastDate: DateTime.now().add(Duration(days: 1825)),
          saveText: "Selecionar",
          helpText: "Selecionar intervalo",
          locale: Locale('pt', "BR"),
        );

        if (picked != null && onSelected != null) {
          onSelected!(picked);
        }
      },
    );
  }

  String formatDate(DateTimeRange? period) {
    String periodFormated = "";

    if (period != null) {
      periodFormated = ModernFormUtils.dateFormat.format(period.start);
    }

    if (period != null && period.end != DateTime(0, 0, 0)) {
      periodFormated += " - ${ModernFormUtils.dateFormat.format(period.end)}";
    }

    return periodFormated;
  }
}

==> 1.0.6.tar.gz: lib/src/core/widgets/pickers/ModernFormDateRangePicker.dart <==
part of modern_form_core;

class ModernFormDateRangePicker extends StatelessWidget {
  final String? label;
  final String? helperText;
  final Icon? prefixIcon;
  final DateTimeRange? initialValute;
  final void Function(DateTimeRange selecteds)? onSelected;
  final bool? sufixCloseEnabled;
  final bool? enabled;
  final String? Function(dynamic)? validator;

  const ModernFormDateRangePicker({
    Key? key,
    this.label,
    this.initialValute,
    this.prefixIcon,
    this.onSelected,
    this.sufixCloseEnabled = true,
    this.enabled,
    this.validator,
    this.helperText,
  });

  @override
  Widget build(BuildContext context) {
    DateTimeRange initialDateRange;
    initialDateRange = DateTimeRange(
      start: initialValute?.start ?? DateTime.now(),
      end: initialValute?.end ?? DateTime.now().add(Duration(days: 7)),
    );

    return ModernFormFakeTextField(
      label: label ?? "",
      helperText: helperText,
      validator: validator,
      initialValue: formatDate(initialDateRange),
      sufixIconEnabled: sufixCloseEnabled != null && sufixCloseEnabled!,
      enabled: enabled ?? true,
      onTap: () async {
        DateTimeRange? picked = await showDateRangePicker(
          context: context,
          initialDateRange: initialDateRange,
          firstDate: DateTime(2020, 01, 01, 00, 00),
          lastDate: DateTime.now().add(Duration(days: 1825)),
          saveText: "Selecionar",
          helpText: "Selecionar intervalo",
          locale: Locale('pt', "BR"),
        );

        if (picked != null && onSelected != null) {
          onSelected!(picked);
        }
      },
    );
  }

  String formatDate(DateTimeRange? period) {
    String periodFormated = "";

    if (period != null) {
      periodFormated = ModernFormUtils.dateFormat.format(period.start);
    }

    if (period != null && period.end != DateTime(0, 0, 0)) {
      periodFormated += " - ${ModernFormUtils.dateFormat.format(period.end)}";
    }

    return periodFormated;
  }
}
